# Other tools

## Compared features

- Attributes (global, per-variable)
- Many-files comparison
- Multiple backends
- Quite/verbose modes
- Comparison tolerance (global, per-variable)

## Compared tools

### recursive_diff/ncdiff

`ncdiff` is part of the `recursive_diff` Python package.
It allows to perform many-files comparison, change the comparison backend, use the quite mode, and apply comparison tolerances (relative and/or absolute).
Furthermore, it has a verbose and brief comparison modes, where are value differences or just their number is shown.

### ncccmp

## Comparison table
